@@ -22,9 +22,8 @@ def register_resource_id(cli):
 
 
 def _check_for_resource_id(param, value, **kwargs):
-    if hasattr(param, 'shape_name'):
-        if param.shape_name == 'ResourceId':
-            orig_value = value
-            value = value.split('/')[-1]
-            logger.debug('ResourceId %s -> %s', orig_value, value)
-            return value
+    if param.name == 'ResourceId':
+        orig_value = value
+        value = value.split('/')[-1]
+        logger.debug('ResourceId %s -> %s', orig_value, value)
+        return value
